@@ -37,9 +37,9 @@ extends TestCase implements TelnetNotificationHandler
      * used in testing for clarity.
      */
     private class TestConnection {
-        TelnetTestSimpleServer server;
-        TelnetClient client;
-        int port;
+        private final TelnetTestSimpleServer server;
+        private final TelnetClient client;
+        private final int port;
         TestConnection(
                 TelnetTestSimpleServer server,
                 TelnetClient client,
@@ -89,6 +89,8 @@ extends TestCase implements TelnetNotificationHandler
                         client = new TelnetClient();
                         // redundant but makes code clearer.
                         client.setReaderThread(true);
+                        client.connect("127.0.0.1", port);
+                        STANDARD = new TestConnection(server, client, port);
                         break;
                     case 1:
                         client = new TelnetClient();
@@ -102,32 +104,21 @@ extends TestCase implements TelnetNotificationHandler
                         client.addOptionHandler(ttopt);
                         client.addOptionHandler(echoopt);
                         client.addOptionHandler(gaopt);
+                        client.connect("127.0.0.1", port);
+                        OPTIONS = new TestConnection(server, client, port);
                         break;
                     case 2:
                         client = new TelnetClient("ANSI");
+                        client.connect("127.0.0.1", port);
+                        ANSI = new TestConnection(server, client, port);
                         break;
                     case 3:
                         client = new TelnetClient();
                         client.setReaderThread(false);
-                        break;
-               }
-               client.connect("127.0.0.1", port);
-               switch (socket) {
-                    case 0:
-                        STANDARD = new TestConnection(server, client, port);
-                        break;
-                    case 1:
-                        OPTIONS = new TestConnection(server, client, port);
-                        break;
-                    case 2:
-                        ANSI = new TestConnection(server, client, port);
-                        break;
-                    case 3:
+                        client.connect("127.0.0.1", port);
                         NOREAD = new TestConnection(server, client, port);
                         break;
-
                }
-
                // only increment socket number on success
                socket++;
            } catch (IOException e) {
@@ -230,8 +221,9 @@ extends TestCase implements TelnetNotificationHandler
             is2.read(buffread2);
             connect2_ok = true;
 
-            if(equalBytes(buffread2, expected2))
-                 init2_ok = true;
+            if (equalBytes(buffread2, expected2)) {
+                init2_ok = true;
+            }
         }
 
         InputStream is3 = ANSI.server.getInputStream();
@@ -355,8 +347,9 @@ extends TestCase implements TelnetNotificationHandler
         {
             is1.read(buffread1);
 
-            if(equalBytes(buffread1, expected1))
+            if (equalBytes(buffread1, expected1)) {
                 negotiation1_ok = true;
+            }
         }
 
         InputStream is2 = OPTIONS.server.getInputStream();
@@ -370,8 +363,9 @@ extends TestCase implements TelnetNotificationHandler
         {
             is2.read(buffread2);
 
-            if(equalBytes(buffread2, expected2))
+            if (equalBytes(buffread2, expected2)) {
                 negotiation2_ok = true;
+            }
 
             if(negotiation2_ok)
             {
@@ -383,8 +377,9 @@ extends TestCase implements TelnetNotificationHandler
                 {
                     is2.read(buffread2b);
 
-                    if(equalBytes(buffread2b, expected2b))
+                    if (equalBytes(buffread2b, expected2b)) {
                         negotiation2_ok = true;
+                    }
                 }
             }
         }
@@ -400,8 +395,9 @@ extends TestCase implements TelnetNotificationHandler
         {
             is3.read(buffread3);
 
-            if(equalBytes(buffread3, expected3))
+            if (equalBytes(buffread3, expected3)) {
                 negotiation3_ok = true;
+            }
 
             if(negotiation3_ok)
             {
@@ -412,8 +408,9 @@ extends TestCase implements TelnetNotificationHandler
                 if(is3.available() == 10)
                 {
                     is3.read(buffread3b);
-                    if(equalBytes(buffread3b, expected3b))
-                            negotiation3_ok = true;
+                    if (equalBytes(buffread3b, expected3b)) {
+                        negotiation3_ok = true;
+                    }
                 }
             }
         }
@@ -483,8 +480,9 @@ extends TestCase implements TelnetNotificationHandler
         {
             is.read(buffread);
 
-            if(equalBytes(buffread, expected))
+            if (equalBytes(buffread, expected)) {
                 negotiation1_ok = true;
+            }
 
             if(negotiation1_ok)
             {
@@ -495,8 +493,9 @@ extends TestCase implements TelnetNotificationHandler
                 if(is.available() == 3)
                 {
                     is.read(buffread2);
-                    if(equalBytes(buffread2, expected2))
-                            negotiation1_ok = true;
+                    if (equalBytes(buffread2, expected2)) {
+                        negotiation1_ok = true;
+                    }
                 }
             }
         }
@@ -617,8 +616,9 @@ extends TestCase implements TelnetNotificationHandler
             if(is.available() == 6)
             {
                 is.read(buffread);
-                if(equalBytes(buffread, expected))
+                if (equalBytes(buffread, expected)) {
                     remove_ok = true;
+                }
             }
         }
 
@@ -674,16 +674,18 @@ extends TestCase implements TelnetNotificationHandler
         assertNotNull(tr);
         boolean res1 = ANSI.client.sendAYT(2000);
 
-        if(res1 == true)
+        if (res1 == true) {
             ayt_true_ok=true;
+        }
 
         Thread.sleep(1000);
         is.skip(is.available());
 
         boolean res2 = ANSI.client.sendAYT(2000);
 
-        if(res2 == false)
+        if (res2 == false) {
             ayt_false_ok=true;
+        }
 
 
         assertTrue(ayt_true_ok);
@@ -721,8 +723,9 @@ extends TestCase implements TelnetNotificationHandler
         if(pi.available() == 5)
         {
             pi.read(buffer);
-            if(equalBytes(buffer, expected1))
+            if (equalBytes(buffer, expected1)) {
                 test1spy_ok = true;
+            }
         }
 
         ostc.write("test2".getBytes());
@@ -733,8 +736,9 @@ extends TestCase implements TelnetNotificationHandler
         if(pi.available() == 5)
         {
             pi.read(buffer);
-            if(equalBytes(buffer, expected2))
+            if (equalBytes(buffer, expected2)) {
                 test2spy_ok = true;
+            }
         }
 
         STANDARD.client.stopSpyStream();
@@ -805,9 +809,10 @@ extends TestCase implements TelnetNotificationHandler
                 pos+=read;
             }
 
-            if(equalBytes(buffread1, expected1))
+            if (equalBytes(buffread1, expected1)) {
                 negotiation1_ok = true;
         //}
+            }
 
 
         InputStream is2 = STANDARD.server.getInputStream();
@@ -828,9 +833,10 @@ extends TestCase implements TelnetNotificationHandler
         //{
             is2.read(buffread1);
 
-            if(equalBytes(buffread1, expected1))
+            if (equalBytes(buffread1, expected1)) {
                 negotiation2_ok = true;
         //}
+            }
 
         assertTrue(!NOREAD.client.getReaderThread());
         assertTrue(STANDARD.client.getReaderThread());
@@ -855,8 +861,9 @@ extends TestCase implements TelnetNotificationHandler
             for(int ii=0; ii<a1.length; ii++)
             {
 
-                if(a1[ii]!= a2[ii])
+                if (a1[ii]!= a2[ii]) {
                     result = false;
+                }
             }
             return(result);
         }
